@@ -14,7 +14,7 @@ or
 
   apt_update();
   apt_upgrade();
-  apt_install(['nginx-common', 'redis-server']);
+  apt_install ['nginx-common', 'redis-server'];
 
 =head1 DESCRIPTION
 
@@ -24,15 +24,18 @@ Provides system utilities such as installing packages, managing files, and more.
 
 use strict;
 use warnings;
+no warnings 'experimental::signatures';
+use feature 'signatures';
 use Path::Tiny;
 use IPC::Run qw(run timeout);
 use English;
 use Module::Runtime qw(use_package_optimistically);
-use Params::Util qw(_HASHLIKE);
+use Params::Util qw(_HASH);
 use Config::Tiny;
+use boolean;
 use base "Exporter::Tiny";
 
-our @EXPORT = qw/execute
+our @EXPORT = qw/sh
   apt_install
   apt_upgrade
   apt_update
@@ -52,56 +55,49 @@ our @EXPORT = qw/execute
 
 =over 8
 
-=item spew
+=item spew(STR $path, STR $contents)
 
 writes to a file, defaults to utf8
 
 =cut
 
-sub spew {
-    my $path     = path(shift);
-    my $contents = shift;
+sub spew ($path, $contents) {
+    $path = path($path);
     $path->spew_utf8($contents);
 }
 
-=item slurp
+=item slurp(STR $path)
 
 reads a file, defaults to utf8
 
 =cut
 
-sub slurp {
-    my $path = path(shift);
+sub slurp($path) {
+    $path = path($path);
     return $path->slurp_utf8;
 }
 
-=item make_dir
+=item make_dir(STR $dir)
 
 mkdir helper for creating directories
 
 =cut
 
-sub make_dir {
-    my $dirs = shift;
-    foreach my $dir (@{$dirs}) {
-        path($dir)->mkpath;
-    }
+sub make_dir($dir) {
+    path($dir)->mkpath;
 }
 
-=item remove_dir
+=item remove_dir(STR $dir)
 
 removes directories
 
 =cut
 
-sub remove_dir {
-    my $dirs = shift;
-    foreach my $dir (@{$dirs}) {
-        path($dir)->remove_tree;
-    }
+sub remove_dir($dir) {
+    path($dir)->remove_tree;
 }
 
-=item set_owner
+=item set_owner(STR $user, ARRAYREF $dirs)
 
 sets owner of directories
 
@@ -109,31 +105,28 @@ sets owner of directories
 
 =cut
 
-sub set_owner {
-    my ($user, $dirs) = @_;
+sub set_owner ($user, $dirs) {
     foreach my $dir (@{$dirs}) {
-        execute(['chown', $user, '-R', $dir]);
+        sh(['chown', $user, '-R', $dir]);
     }
 }
 
 
-=item getent
+=item getent(STR $db, STR $key)
 
 accesses user info from nss
 
 B<Params>
 
-=for :list
 *  db: nss database to query
 *  key: what to query
-*  returns: result from C<execute>
+*  returns: result from C<sh>
 
 =cut
 
-sub getent {
-    my ($db, $key) = @_;
+sub getent ($db, $key) {
     if ($OSNAME eq 'linux') {
-        my $ret = execute(['getent', $db, $key]);
+        my $ret = sh(['getent', $db, $key]);
         return $ret;
     }
     else {
@@ -142,60 +135,53 @@ sub getent {
     }
 }
 
-=item add_user
+=item add_user(STR $user, STR $homedir)
 
 adds user to system
 
 B<Params>
 
-=for :list
 * user: username
 * homedir: users home directory
-* returns: result from C<execute>
+* returns: result from C<sh>
 
 =cut
 
-sub add_user {
-    my $user    = shift;
-    my $homedir = shift || undef;
-    my $cmd     = ['adduser', '--gecos ""', '--disabled-password'];
+sub add_user ($user, $homedir = false) {
+    my $cmd = ['adduser', '--gecos ""', '--disabled-password'];
     if ($homedir) {
         push @{$cmd}, ['--home', $homedir];
     }
-    my $ret = execute($cmd);
+    my $ret = sh($cmd);
     return $ret;
 }
 
-=item del_user
+=item del_user(STR $user)
 
 removes a user, does attempt to remove home directory
 
 =cut
 
-sub del_user {
-    my $user = shift;
-    my $ret = execute(['deluser', '--remove-home', $user]);
+sub del_user($user) {
+    my $ret = sh(['deluser', '--remove-home', $user]);
     return $ret;
 }
 
-=item execute
+=item sh(ARRAYREF $command)
 
-Executes a local command:
+Shs a local command:
 
-   my $cmd = ['juju-log', 'a message'];
-   my $ret = execute($cmd);
+   my $ret = sh(['juju-log', 'a message']);
    print $ret->{stdout};
 
 B<Params>
 
-=for :list
 * command: command to run
 * returns: hash of { stdout =>, stderr =>, has_error =>, error => }
 
 =cut
 
-sub execute {
-    my ($command) = @_;
+sub sh($command) {
     my $result = run $command, \my $stdin, \my $stdout, \my $stderr;
     chomp for ($stdout, $stderr);
 
@@ -207,7 +193,7 @@ sub execute {
 }
 
 
-=item apt_add_repo
+=item apt_add_repo(STR $repo, STR $key, BOOL $update)
 
 Adds a archive repository or ppa. B<key> is required if adding http source.
 
@@ -218,18 +204,15 @@ B<source> can be in the format of:
 
 =cut
 
-sub apt_add_repo {
-    my $repo   = shift;
-    my $update = shift || 0;
-    my $key    = shift || undef;
+sub apt_add_repo ($repo, $key = undef, $update = false) {
     if ($repo =~ /^(ppa:|cloud:|http|deb|cloud-archive:)/) {
-        execute(['apt-add-repository', '--yes', $repo]);
+        sh(['apt-add-repository', '--yes', $repo]);
     }
     if ($repo =~ /^cloud:/) {
         apt_install(['ubuntu-cloud-keyring']);
     }
     if ($key) {
-        execute(
+        sh(
             [   'apt-key', 'adv', '--keyserver',
                 'hkp://keyserver.ubuntu.com:80',
                 '--recv', $key
@@ -241,7 +224,7 @@ sub apt_add_repo {
     }
 }
 
-=item apt_install
+=item apt_install(ARRAYREF $pkgs)
 
 Installs packages via apt-get
 
@@ -249,11 +232,10 @@ Installs packages via apt-get
 
 =cut
 
-sub apt_install {
-    my $pkgs = shift;
+sub apt_install($pkgs) {
     my $cmd = ['apt-get', '-qyf', 'install'];
     map { push @{$cmd}, $_ } @{$pkgs};
-    my $ret = execute($cmd);
+    my $ret = sh($cmd);
     return $ret->{stdout};
 }
 
@@ -267,7 +249,7 @@ Upgrades system
 
 sub apt_upgrade {
     my $cmd = ['apt-get', '-qyf', 'dist-upgrade'];
-    my $ret = execute($cmd);
+    my $ret = sh($cmd);
     return $ret->{stdout};
 }
 
@@ -281,39 +263,36 @@ Update repository sources
 
 sub apt_update {
     my $cmd = ['apt-get', 'update'];
-    my $ret = execute($cmd);
+    my $ret = sh($cmd);
     return $ret->{stdout};
 }
 
 
-=item service_control
+=item service_control(STR $service_name, STR $action)
 
 Controls a upstart service
 
 =cut
 
-sub service_control {
-    my $service_name = shift;
-    my $action       = shift;
-    my $cmd          = ['systemctl', $action, $service_name];
-    my $ret          = execute($cmd);
+sub service_control ($service_name, $action) {
+    my $cmd = ['systemctl', $action, $service_name];
+    my $ret = sh($cmd);
     return $ret;
 }
 
-=item service_status
+=item service_status(STR $service_name)
 
 Get running status of service
 
 =cut
 
-sub service_status {
-    my $service_name = shift;
+sub service_status($service_name) {
     my $ret = service_control($service_name, 'status');
     return $ret->{error};
 }
 
 
-=item load_helper($opts)
+=item load_helper(STR $name, HASHREF $opts)
 
 Helper for bringing in additional utilities. A lot of utilities are
 exported automatically however, this is useful if more control is
@@ -325,30 +304,28 @@ B<Params>
 
 =cut
 
-sub load_helper {
-    my $name  = shift;
-    my $opts  = _HASHLIKE(shift) or die "Options should be a HASHREF";
+sub load_helper ($name, $opts) {
+    _HASH($opts) or die "Options should be a HASH";
     my $klass = "App::CharmKit::$name";
     return use_package_optimistically($klass)->new(%{$opts});
 }
 
 
-=item read_ini
+=item read_ini(STR $path)
 
 Basic config parsing for ini like files like whats found in most of B</etc/default>.
 This will also automatically return its root property.
 
 B<Params>
 
-=for :list
 * C<path>
 Path of config file to read
 
 =cut
 
-sub read_ini {
-    my $path = path(shift);
-    my $cfg  = Config::Tiny->new;
+sub read_ini($path) {
+    $path = path($path);
+    my $cfg = Config::Tiny->new;
     return $cfg->read($path)->{_};
 }
 
